summaryrefslogtreecommitdiffstats
path: root/src/DabMux.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/DabMux.cpp')
-rw-r--r--src/DabMux.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/DabMux.cpp b/src/DabMux.cpp
index 4e10287..2ef28c9 100644
--- a/src/DabMux.cpp
+++ b/src/DabMux.cpp
@@ -7,20 +7,20 @@
2012, Matthias P. Braendli, matthias.braendli@mpb.li
*/
/*
- This file is part of CRC-DabMux.
+ This file is part of ODR-DabMux.
- CRC-DabMux is free software: you can redistribute it and/or modify
+ ODR-DabMux is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.
- CRC-DabMux is distributed in the hope that it will be useful,
+ ODR-DabMux is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with CRC-DabMux. If not, see <http://www.gnu.org/licenses/>.
+ along with ODR-DabMux. If not, see <http://www.gnu.org/licenses/>.
*/
#ifdef HAVE_CONFIG_H
@@ -322,7 +322,7 @@ int main(int argc, char *argv[])
/* TODO:
* In a SFN, when reconfiguring the ensemble, the multiplexer
* has to be restarted (crc-dabmux doesn't support reconfiguration).
* Ideally, we must be able to restart transmission s.t. the receiver
* synchronisation is preserved.
*/
@@ -373,7 +373,7 @@ int main(int argc, char *argv[])
}
- etiLog.log(info, "CRC-DABMUX starting up");
+ etiLog.log(info, "ODR-DabMux starting up");
if (outputs.size() == 0) {
etiLog.log(emerg, "no output defined");
@@ -322,7 +322,7 @@ int main(int argc, char *argv[])
/* TODO:
* In a SFN, when reconfiguring the ensemble, the multiplexer
- * has to be restarted (crc-dabmux doesn't support reconfiguration).
+ * has to be restarted (odr-dabmux doesn't support reconfiguration).
* Ideally, we must be able to restart transmission s.t. the receiver
* synchronisation is preserved.